@@ -133,17 +133,17 @@ class Functions:
                 if getattr(self.result, key) not in self.allowed[key]:
                     break
             else:
-                self.last['second'] = self.result.second
-                if self.last['second'] == self.allowed['second'][-1]:
-                    self.last['second'] = -1
+                self.last[self.allowed_keys[0]] = self.result.second
+                if self.last[self.allowed_keys[0]] == self.allowed[self.allowed_keys[0]][-1]:
+                    self.last[self.allowed_keys[0]] = -1
                 result = self.result
-                self.result += timedelta(seconds=1)
+                self.result += timedelta(**{self.allowed_keys[0] + 's': 1})
                 return result
 
-        result = self.__iterator('second')
+        result = self.__iterator(self.allowed_keys[0])
         if isinstance(result, datetime):
-            if self.last['second'] == self.allowed['second'][-1]:
-                self.last['second'] = -1
+            if self.last[self.allowed_keys[0]] == self.allowed[self.allowed_keys[0]][-1]:
+                self.last[self.allowed_keys[0]] = -1
             self.result = result
             return result
         elif (
@@ -170,14 +170,21 @@ class Functions:
             return self.gen_next()
         elif (
                 self.allowed['day'] and self.allowed['day'][-1] > self.result.day
-        ) and self.result.month in self.allowed['month']:
+        ) and (
+                self.result.month in self.allowed['month']
+        ) and (
+                calendar.monthrange(self.result.year, self.result.month)[-1] > self.result.day
+        ):
             self.last['day'] = self.result.day
-            self.result = self.result.replace(
-                day=list(filter(lambda x: x > self.result.day, self.allowed['day']))[0],
-                hour=0,
-                minute=0,
-                second=0
-            )
+            try:
+                self.result = self.result.replace(
+                    day=list(filter(lambda x: x > self.result.day, self.allowed['day']))[0],
+                    hour=0,
+                    minute=0,
+                    second=0
+                )
+            except:
+                print(1)
             self.last['second'] = -1
             self.last['minute'] = -1
             self.last['hour'] = -1
@@ -351,8 +358,10 @@ class Functions:
                 else:
                     # Что-то не помню зачем так сделал, возможен отстрел
                     _allowed = {allowed[0]}
-            elif part_of_parts.isdigit():
+            elif part_of_parts.isdigit() and name!='day_of_week':
                 _allowed.update(set(allowed) & {int(part_of_parts)})
+            elif name == 'day_of_week':
+                _allowed.add(int(part_of_parts))
             else:
                 raise Exception('Не удалось распознать содержимое левой части {}, а конкретно {}'.format(
                     lparts, part_of_parts
@@ -390,6 +399,7 @@ class Functions:
                     if isinstance(giterator, str) and 'L' in giterator and _allowed_wdays:
                         # Если мы нашли нужный день, дальше итерироваться не стоит
                         break
+
                     for _allow in _allowed:
                         if isinstance(giterator, str) and '/' in giterator:
                             _allowed_wdays.update({d for d in week[_allow % 7::int(giterator[1:])] if d > 0})
@@ -399,5 +409,6 @@ class Functions:
                                 if isinstance(giterator, str) and 'L' in giterator:
                                     # Если мы нашли нужный день, дальше итерироваться не стоит
                                     break
+
                 _allowed = _allowed_wdays
         return _allowed
